==> cxf-testutils-2.0.6.11-fuse-sources.jar: org/apache/type_test/doc/TestBooleanResponse.java <==

package org.apache.type_test.doc;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for testBooleanResponse element declaration.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;element name="testBooleanResponse">
 *   &lt;complexType>
 *     &lt;complexContent>
 *       &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *         &lt;sequence>
 *           &lt;element name="return" type="{http://www.w3.org/2001/XMLSchema}boolean"/>
 *           &lt;element name="y" type="{http://www.w3.org/2001/XMLSchema}boolean"/>
 *           &lt;element name="z" type="{http://www.w3.org/2001/XMLSchema}boolean"/>
 *         &lt;/sequence>
 *       &lt;/restriction>
 *     &lt;/complexContent>
 *   &lt;/complexType>
 * &lt;/element>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "_return",
    "y",
    "z"
})
@XmlRootElement(name = "testBooleanResponse")
public class TestBooleanResponse {

    @XmlElement(name = "return", namespace = "http://apache.org/type_test/doc")
    protected boolean _return;
    @XmlElement(namespace = "http://apache.org/type_test/doc")
    protected boolean y;
    @XmlElement(namespace = "http://apache.org/type_test/doc")
    protected boolean z;

    /**
     * Gets the value of the return property.
     * 
     */
    public boolean isReturn() {
        return _return;
    }

    /**
     * Sets the value of the return property.
     * 
     */
    public void setReturn(boolean value) {
        this._return = value;
    }

    /**
     * Gets the value of the y property.
     * 
     */
    public boolean isY() {
        return y;
    }

    /**
     * Sets the value of the y property.
     * 
     */
    public void setY(boolean value) {
        this.y = value;
    }

    /**
     * Gets the value of the z property.
     * 
     */
    public boolean isZ() {
        return z;
    }

    /**
     * Sets the value of the z property.
     * 
     */
    public void setZ(boolean value) {
        this.z = value;
    }

}

==> cxf-testutils-2.1.3.13-fuse-sources.jar: org/apache/type_test/doc/TestBooleanResponse.java <==

package org.apache.type_test.doc;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element name="return" type="{http://www.w3.org/2001/XMLSchema}boolean"/>
 *         &lt;element name="y" type="{http://www.w3.org/2001/XMLSchema}boolean"/>
 *         &lt;element name="z" type="{http://www.w3.org/2001/XMLSchema}boolean"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "_return",
    "y",
    "z"
})
@XmlRootElement(name = "testBooleanResponse")
public class TestBooleanResponse {

    @XmlElement(name = "return")
    protected boolean _return;
    protected boolean y;
    protected boolean z;

    /**
     * Gets the value of the return property.
     * 
     */
    public boolean isReturn() {
        return _return;
    }

    /**
     * Sets the value of the return property.
     * 
     */
    public void setReturn(boolean value) {
        this._return = value;
    }

    /**
     * Gets the value of the y property.
     * 
     */
    public boolean isY() {
        return y;
    }

    /**
     * Sets the value of the y property.
     * 
     */
    public void setY(boolean value) {
        this.y = value;
    }

    /**
     * Gets the value of the z property.
     * 
     */
    public boolean isZ() {
        return z;
    }

    /**
     * Sets the value of the z property.
     * 
     */
    public void setZ(boolean value) {
        this.z = value;
    }

}
